import 'dart:io';

import '../lib/models/task.dart';
import '../lib/logic/task_manager.dart';
import '../lib/services/task_storage.dart';

void main() async {
  final taskManager = TaskManager();
  final storage = TaskStorage();

  // Aufgaben beim Start laden
  final loadedTasks = await storage.loadTasks();
  taskManager.loadFromList(loadedTasks);

  print('📝 Aufgabenmanager gestartet!');
  bool running = true;

  while (running) {
    print('\nWas möchtest du tun?');
    print('1. Aufgaben anzeigen');
    print('2. Neue Aufgabe hinzufügen');
    print('3. Aufgabe als erledigt markieren');
    print('4. Aufgaben speichern');
    print('5. Beenden');

    stdout.write('> ');
    final input = stdin.readLineSync();

    switch (input) {
      case '1':
        taskManager.listTasks();
        break;
      case '2':
        stdout.write('Aufgabentitel: ');
        final title = stdin.readLineSync();
        if (title != null && title.trim().isNotEmpty) {
          taskManager.addTask(title.trim());
        } else {
          print('❌ Ungültiger Titel.');
        }
        break;
      case '3':
        stdout.write('ID der Aufgabe: ');
        final idInput = stdin.readLineSync();
        final id = int.tryParse(idInput ?? '');
        if (id != null) {
          try {
            taskManager.markTaskAsDone(id);
          } catch (e) {
            print('❌ ${e.toString()}');
          }
        } else {
          print('❌ Ungültige ID.');
        }
        break;
      case '4':
        await storage.saveTasks(taskManager.tasks);
        print('✅ Aufgaben gespeichert.');
        break;
      case '5':
        print('📦 Aufgaben werden gespeichert und Programm beendet...');
        await storage.saveTasks(taskManager.tasks);
        running = false;
        break;
      default:
        print('❗ Ungültige Eingabe.');
    }
  }

  print('👋 Auf Wiedersehen!');
}


