import '../models/task.dart';

class TaskManager {
  final List<Task> _tasks = [];
  int _nextId = 1;

  List<Task> get tasks => List.unmodifiable(_tasks);

  void addTask(String title) {
    final task = Task(id: _nextId++, title: title);
    _tasks.add(task);
    print('Aufgabe hinzugefügt: $task');
  }

  void markTaskAsDone(int id) {
    final task = _tasks.firstWhere(
      (t) => t.id == id,
      orElse: () => throw Exception('Aufgabe mit ID $id nicht gefunden.'),
    );
    task.isDone = true;
    print('Aufgabe erledigt: $task');
  }

  void listTasks() {
    if (_tasks.isEmpty) {
      print('Keine Aufgaben vorhanden.');
    } else {
      for (var task in _tasks) {
        print(task);
      }
    }
  }

  void clearTasks() {
    _tasks.clear();
    _nextId = 1;
  }

  void loadFromList(List<Task> taskList) {
    _tasks.clear();
    _tasks.addAll(taskList);
    _nextId = _tasks.isEmpty ? 1 : _tasks.map((t) => t.id).reduce((a, b) => a > b ? a : b) + 1;
  }
}
